==> mingw-w64-rio-0.1.17-1.src.tar.zst: rio-0.1.17/docs/src/data/mentions.js <==
// @ts-check

/** @satisfies {import('@site/src/components/MentionsSection/index').MentionCardProps[]} */
const MENTIONS = [
  {
    url: 'https://twitter.com/jaijams/status/1716815864975270005',
    username: '@jaijams',
    source: '/rio/assets/mentions/jaijams.jpg',
    quote: (
      <>
        I have been using the Rio terminal (https://raphamorim.io/rio/) for 6
        months. OMG! Rio is my No.1 terminal ♥️ and is super fast 🚀 . Love
        using it daily 🎉
      </>
    ),
  },
  {
    url: '',
    username: 'Simon Nyberg',
    source: '/rio/assets/mentions/simonnyberg.png',
    quote: (
      <>
        Rio has become my standard terminal emulator for some time and it works well in professional use. Raphael is doing a great work and is awesome at listening to feedback to the community for new and improved features.
      </>
    ),
  },
  {
    url: 'https://twitter.com/mcsmonte/status/1660949303089586177',
    username: '@mcsmonte',
    source: '/rio/assets/mentions/mcsmonte.jpg',
    quote: (
      <>
        This week I'm testing rio, a rust based terminal and I need to say: It's
        amazing! either still beta, could full fill all need working heavily
        with git/docker/spring/npm , I really recommend to get a try and Kudos
        to @raphamorims for fantastic job
      </>
    ),
  },
  {
    url: 'https://twitter.com/moeyua13/status/1665983183526195200',
    username: '@moeyua13',
    source: 'https://unavatar.io/x/moeyua13',
    quote: <>I really love this terminal</>,
  },
  {
    url: 'https://twitter.com/peterlazar1993/status/1689965895408402432',
    username: '@peterlazar1993',
    source: 'https://unavatar.io/x/peterlazar1993',
    quote: <>I've been dailydriving Rio, it's 🔥</>,
  },
  {
    url: 'https://twitter.com/EduRonqui/status/1717288090820055297',
    username: '@EduRonqui',
    source: 'https://unavatar.io/x/EduRonqui',
    quote: (
      <>
        It’s a tiny one but this release features my first ever contribution to
        an open source project and it feels so nice to give back to this amazing
        project that has become my main terminal.
      </>
    ),
  },
  {
    url: 'https://x.com/ferfabricio/status/1789425980357886355',
    username: '@ferfabricio',
    source: '/rio/assets/mentions/ferfabricio.jpg',
    quote: (
      <>
        Eu comecei a usar o Rio term faz uns dias e ta sendo uma experiência
        muito bacana! parabéns @raphamorims
      </>
    ),
  },
  {
    url: '#',
    username: 'Jader Gomes',
    source: '/rio/assets/mentions/jadergomes.jpg',
    quote: (
      <>
        Have been using Rio for few weeks and enjoying the experience so far. I love the colors and the visual around it.
      </>
    ),
  },
  {
    url: '#',
    username: 'Daria Edlund',
    source: '/rio/assets/mentions/dariaedlund.png',
    quote: (
      <>
        Installed Rio recently and am impressed how smooth and fast this terminal is. Already set up as my default go-to terminal! Looking forward to the continued development and what is to come. Keep up the awesome job Raphael!
      </>
    ),
  },
  {
    url: 'https://x.com/avelinorun/',
    username: 'Thiago Avelino',
    source: '/rio/assets/mentions/avelinorun.jpg',
    quote: (
      <>
        It is a privilege to be invited to beta test Rio! It has brought me closer to the code of the project, and I have learned a lot about how to develop a terminal emulator.
      </>
    ),
  },
];

export default MENTIONS;

==> mingw-w64-rio-0.2.1-1.src.tar.zst: rio-0.2.1/docs/src/data/mentions.js <==
// @ts-check

/** @satisfies {import('@site/src/components/MentionsSection/index').MentionCardProps[]} */
const MENTIONS = [
  {
    url: 'https://fosstodon.org/@orhun/113375636616878019',
    username: 'Orhun Parmaksız',
    source: '/rio/assets/mentions/orhun.png',
    quote: (
      <>
        One of the few terminal emulators out there with kickass features!
      </>
    ),
  },
  {
    url: 'https://x.com/kristoferlund/status/1850287561295692226',
    username: 'Kristofer Lund',
    source: '/rio/assets/mentions/kristoferlund.jpg',
    quote: (
      <>
        Love Rio terminal by @raphamorims! Written in Rust = super fast, plus has kick-ass features like this. 👊💥
      </>
    ),
  },
  {
    url: 'https://mas.to/@appelgriebsch@fosstodon.org/113491434980520006',
    username: 'Andreas Gerlach',
    source: '/rio/assets/mentions/andreasgerlach.jpeg',
    quote: (
      <>
        With the recent release of #rio earlier this week it has all the features and polish I need on daily basis, so it became my daily driver immediately....  thanks so much @mustache
      </>
    ),
  },
  {
    url: 'https://twitter.com/jaijams/status/1716815864975270005',
    username: '@jaijams',
    source: '/rio/assets/mentions/jaijams.jpg',
    quote: (
      <>
        I have been using the Rio terminal (https://raphamorim.io/rio/) for 6
        months. OMG! Rio is my No.1 terminal ♥️ and is super fast 🚀 . Love
        using it daily 🎉
      </>
    ),
  },
  {
    url: '',
    username: 'Simon Nyberg',
    source: '/rio/assets/mentions/simonnyberg.png',
    quote: (
      <>
        Rio has become my standard terminal emulator for some time and it works well in professional use. Raphael is doing a great work and is awesome at listening to feedback to the community for new and improved features.
      </>
    ),
  },
  {
    url: 'https://twitter.com/mcsmonte/status/1660949303089586177',
    username: '@mcsmonte',
    source: '/rio/assets/mentions/mcsmonte.jpg',
    quote: (
      <>
        This week I'm testing rio, a rust based terminal and I need to say: It's
        amazing! either still beta, could full fill all need working heavily
        with git/docker/spring/npm , I really recommend to get a try and Kudos
        to @raphamorims for fantastic job
      </>
    ),
  },
  {
    url: 'https://twitter.com/moeyua13/status/1665983183526195200',
    username: '@moeyua13',
    source: 'https://unavatar.io/x/moeyua13',
    quote: <>I really love this terminal</>,
  },
  {
    url: 'https://twitter.com/peterlazar1993/status/1689965895408402432',
    username: '@peterlazar1993',
    source: 'https://unavatar.io/x/peterlazar1993',
    quote: <>I've been dailydriving Rio, it's 🔥</>,
  },
  {
    url: 'https://twitter.com/EduRonqui/status/1717288090820055297',
    username: '@EduRonqui',
    source: 'https://unavatar.io/x/EduRonqui',
    quote: (
      <>
        It’s a tiny one but this release features my first ever contribution to
        an open source project and it feels so nice to give back to this amazing
        project that has become my main terminal.
      </>
    ),
  },
  {
    url: 'https://x.com/ferfabricio/status/1789425980357886355',
    username: '@ferfabricio',
    source: '/rio/assets/mentions/ferfabricio.jpg',
    quote: (
      <>
        Eu comecei a usar o Rio term faz uns dias e ta sendo uma experiência
        muito bacana! parabéns @raphamorims
      </>
    ),
  },
  {
    url: '#',
    username: 'Jader Gomes',
    source: '/rio/assets/mentions/jadergomes.jpg',
    quote: (
      <>
        Have been using Rio for few weeks and enjoying the experience so far. I love the colors and the visual around it.
      </>
    ),
  },
  {
    url: '#',
    username: 'Daria Edlund',
    source: '/rio/assets/mentions/dariaedlund.png',
    quote: (
      <>
        Installed Rio recently and am impressed how smooth and fast this terminal is. Already set up as my default go-to terminal! Looking forward to the continued development and what is to come. Keep up the awesome job Raphael!
      </>
    ),
  },
  {
    url: 'https://x.com/avelinorun/',
    username: 'Thiago Avelino',
    source: '/rio/assets/mentions/avelinorun.jpg',
    quote: (
      <>
        It is a privilege to be invited to beta test Rio! It has brought me closer to the code of the project, and I have learned a lot about how to develop a terminal emulator.
      </>
    ),
  },
  {
    url: 'https://x.com/mkenzo_8',
    username: '@mkenzo_8',
    source: '/rio/assets/mentions/mkenzo_8.jpg',
    quote: (
      <>
        Rio tiene el potencial de ser de las terminales mas rápidas ⚡ y mas personalizables que hay, es una locura.
      </>
    ),
  },
];

export default MENTIONS;
